@@ -1,6 +1,8 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
 
+from hashlib import md5
+
 import marshal
 import json
 import types
@@ -8,6 +10,12 @@ import types
 
 class CallbackSerialize:
 
+    @classmethod
+    def md5sum(cls, serialized):
+        hasher = md5()
+        hasher.update(serialized)
+        return hasher.hexdigest()
+
     @classmethod
     def serialize(cls, function):
         if callable(function):
@@ -16,12 +24,13 @@ class CallbackSerialize:
                             function.func_name,
                             function.func_defaults)
                         )
-            return serialized
+            return (cls.md5sum(serialized), serialized)
 
     @classmethod
     def deserialize(cls, encoded):
         (code, name, defaults) = json.loads(encoded)
         code = marshal.loads(code)
 
-        return types.FunctionType(code, globals=globals(), name=str(name), \
-                                                            argdefs=defaults)
+        return (cls.md5sum(encoded), \
+                types.FunctionType(code, globals=globals(), name=str(name), \
+                                                            argdefs=defaults))
